import numpy as np

def mass_tet4():
    """Basic mass matrix for a 3D tetrahedral element with 4 nodes."""
    return np.array([[2, 0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0],
                    [0, 2, 0, 0, 1, 0, 0, 1, 0, 0, 1, 0],
                    [0, 0, 2, 0, 0, 1, 0, 0, 1, 0, 0, 1],
                    [1, 0, 0, 2, 0, 0, 1, 0, 0, 1, 0, 0],
                    [0, 1, 0, 0, 2, 0, 0, 1, 0, 0, 1, 0],
                    [0, 0, 1, 0, 0, 2, 0, 0, 1, 0, 0, 1],
                    [1, 0, 0, 1, 0, 0, 2, 0, 0, 1, 0, 0],
                    [0, 1, 0, 0, 1, 0, 0, 2, 0, 0, 1, 0],
                    [0, 0, 1, 0, 0, 1, 0, 0, 2, 0, 0, 1],
                    [1, 0, 0, 1, 0, 0, 1, 0, 0, 2, 0, 0],
                    [0, 1, 0, 0, 1, 0, 0, 1, 0, 0, 2, 0],
                    [0, 0, 1, 0, 0, 1, 0, 0, 1, 0, 0, 2]])

def mass_tet10():
    """Basic mass matrix for a 3D tetrahedral element with 10 nodes."""
    return np.array([[  6.,   0.,   0.,   1.,   0.,   0.,   1.,   0.,   0.,   1.,   0.,
                      0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -4.,
                      0.,   0.,  -6.,   0.,   0.,  -6.,   0.,   0.],
                    [  0.,   6.,   0.,   0.,   1.,   0.,   0.,   1.,   0.,   0.,   1.,
                      0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,
                     -4.,   0.,   0.,  -6.,   0.,   0.,  -6.,   0.],
                    [  0.,   0.,   6.,   0.,   0.,   1.,   0.,   0.,   1.,   0.,   0.,
                      1.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,
                      0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -6.],
                    [  1.,   0.,   0.,   6.,   0.,   0.,   1.,   0.,   0.,   1.,   0.,
                      0.,  -4.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -6.,
                      0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.],
                    [  0.,   1.,   0.,   0.,   6.,   0.,   0.,   1.,   0.,   0.,   1.,
                      0.,   0.,  -4.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,
                     -6.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.],
                    [  0.,   0.,   1.,   0.,   0.,   6.,   0.,   0.,   1.,   0.,   0.,
                      1.,   0.,   0.,  -4.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,
                      0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -6.],
                    [  1.,   0.,   0.,   1.,   0.,   0.,   6.,   0.,   0.,   1.,   0.,
                      0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -4.,   0.,   0.,  -6.,
                      0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.],
                    [  0.,   1.,   0.,   0.,   1.,   0.,   0.,   6.,   0.,   0.,   1.,
                      0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -4.,   0.,   0.,
                     -6.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.],
                    [  0.,   0.,   1.,   0.,   0.,   1.,   0.,   0.,   6.,   0.,   0.,
                      1.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -4.,   0.,
                      0.,  -6.,   0.,   0.,  -6.,   0.,   0.,  -4.],
                    [  1.,   0.,   0.,   1.,   0.,   0.,   1.,   0.,   0.,   6.,   0.,
                      0.,  -6.,   0.,   0.,  -6.,   0.,   0.,  -6.,   0.,   0.,  -4.,
                      0.,   0.,  -4.,   0.,   0.,  -4.,   0.,   0.],
                    [  0.,   1.,   0.,   0.,   1.,   0.,   0.,   1.,   0.,   0.,   6.,
                      0.,   0.,  -6.,   0.,   0.,  -6.,   0.,   0.,  -6.,   0.,   0.,
                     -4.,   0.,   0.,  -4.,   0.,   0.,  -4.,   0.],
                    [  0.,   0.,   1.,   0.,   0.,   1.,   0.,   0.,   1.,   0.,   0.,
                      6.,   0.,   0.,  -6.,   0.,   0.,  -6.,   0.,   0.,  -6.,   0.,
                      0.,  -4.,   0.,   0.,  -4.,   0.,   0.,  -4.],
                    [ -4.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -6.,   0.,
                      0.,  32.,   0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.,  16.,
                      0.,   0.,  16.,   0.,   0.,   8.,   0.,   0.],
                    [  0.,  -4.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -6.,
                      0.,   0.,  32.,   0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.,
                     16.,   0.,   0.,  16.,   0.,   0.,   8.,   0.],
                    [  0.,   0.,  -4.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,
                     -6.,   0.,   0.,  32.,   0.,   0.,  16.,   0.,   0.,  16.,   0.,
                      0.,  16.,   0.,   0.,  16.,   0.,   0.,   8.],
                    [ -6.,   0.,   0.,  -4.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,
                      0.,  16.,   0.,   0.,  32.,   0.,   0.,  16.,   0.,   0.,   8.,
                      0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.],
                    [  0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -4.,   0.,   0.,  -6.,
                      0.,   0.,  16.,   0.,   0.,  32.,   0.,   0.,  16.,   0.,   0.,
                      8.,   0.,   0.,  16.,   0.,   0.,  16.,   0.],
                    [  0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -4.,   0.,   0.,
                     -6.,   0.,   0.,  16.,   0.,   0.,  32.,   0.,   0.,  16.,   0.,
                      0.,   8.,   0.,   0.,  16.,   0.,   0.,  16.],
                    [ -4.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,
                      0.,  16.,   0.,   0.,  16.,   0.,   0.,  32.,   0.,   0.,  16.,
                      0.,   0.,   8.,   0.,   0.,  16.,   0.,   0.],
                    [  0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -6.,
                      0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.,  32.,   0.,   0.,
                     16.,   0.,   0.,   8.,   0.,   0.,  16.,   0.],
                    [  0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,
                     -6.,   0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.,  32.,   0.,
                      0.,  16.,   0.,   0.,   8.,   0.,   0.,  16.],
                    [ -4.,   0.,   0.,  -6.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,
                      0.,  16.,   0.,   0.,   8.,   0.,   0.,  16.,   0.,   0.,  32.,
                      0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.],
                    [  0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -6.,   0.,   0.,  -4.,
                      0.,   0.,  16.,   0.,   0.,   8.,   0.,   0.,  16.,   0.,   0.,
                     32.,   0.,   0.,  16.,   0.,   0.,  16.,   0.],
                    [  0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -6.,   0.,   0.,
                     -4.,   0.,   0.,  16.,   0.,   0.,   8.,   0.,   0.,  16.,   0.,
                      0.,  32.,   0.,   0.,  16.,   0.,   0.,  16.],
                    [ -6.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,
                      0.,  16.,   0.,   0.,  16.,   0.,   0.,   8.,   0.,   0.,  16.,
                      0.,   0.,  32.,   0.,   0.,  16.,   0.,   0.],
                    [  0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,  -4.,
                      0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.,   8.,   0.,   0.,
                     16.,   0.,   0.,  32.,   0.,   0.,  16.,   0.],
                    [  0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -6.,   0.,   0.,
                     -4.,   0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.,   8.,   0.,
                      0.,  16.,   0.,   0.,  32.,   0.,   0.,  16.],
                    [ -6.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -4.,   0.,
                      0.,   8.,   0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.,  16.,
                      0.,   0.,  16.,   0.,   0.,  32.,   0.,   0.],
                    [  0.,  -6.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,  -4.,
                      0.,   0.,   8.,   0.,   0.,  16.,   0.,   0.,  16.,   0.,   0.,
                     16.,   0.,   0.,  16.,   0.,   0.,  32.,   0.],
                    [  0.,   0.,  -6.,   0.,   0.,  -6.,   0.,   0.,  -4.,   0.,   0.,
                     -4.,   0.,   0.,   8.,   0.,   0.,  16.,   0.,   0.,  16.,   0.,
                      0.,  16.,   0.,   0.,  16.,   0.,   0.,  32.]])